==> haskell-ghc-typelits-extra-0.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-extra
version: 0.3
id: ghc-typelits-extra-0.3-Fu4ROSONlGO65NyLLszh0N
key: ghc-typelits-extra-0.3-Fu4ROSONlGO65NyLLszh0N
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic B.V.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://www.clash-lang.org/
synopsis: Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:
    .
    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>
    .
    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>
    .
    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>
    .
    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>
    .
    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@
    .
    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@
    .
    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@
    .
    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>
    .
    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>
    .
    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @
    .
    pragma to the header of your file.
category: Type System
abi: 57a52c07f2d43eaf6be51f9611bac869
exposed: True
exposed-modules:
    GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules: GHC.TypeLits.Extra.Solver.Unify
                GHC.TypeLits.Extra.Solver.Operations
import-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-typelits-extra-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-typelits-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ghc-typelits-extra-0.3
hs-libraries: HSghc-typelits-extra-0.3-Fu4ROSONlGO65NyLLszh0N
depends:
    base-4.11.1.0 ghc-8.4.3 ghc-prim-0.5.2.0
    ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
    ghc-typelits-knownnat-0.6-2l65EuMUsdqFInKH66lzYd
    ghc-typelits-natnormalise-0.6.2-EIVHJpQRDQbDkaHy66XoaR
    integer-gmp-1.0.2.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-8.4.3=b85a78185b88bdae88410d8ef8f69684
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB=ce7823a6fd180b4f7432a3604d6a13e8
             ghc-typelits-knownnat-0.6-2l65EuMUsdqFInKH66lzYd=65a99784148690104913d2bc9039187e
             ghc-typelits-natnormalise-0.6.2-EIVHJpQRDQbDkaHy66XoaR=ed21f943764f1838268a3e51ae0a64b5
             integer-gmp-1.0.2.0=9ea484dc1eeb054803bb4cf8d65c934d
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-extra-0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-extra
version: 0.3
id: ghc-typelits-extra-0.3-3auTPQpl7g3D09kZafSvUS
key: ghc-typelits-extra-0.3-3auTPQpl7g3D09kZafSvUS
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic B.V.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://www.clash-lang.org/
synopsis: Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:
    .
    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>
    .
    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>
    .
    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>
    .
    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>
    .
    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@
    .
    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@
    .
    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@
    .
    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>
    .
    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>
    .
    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @
    .
    pragma to the header of your file.
category: Type System
abi: 508d0bd41744fe45b388eb19d7532e3f
exposed: True
exposed-modules:
    GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules: GHC.TypeLits.Extra.Solver.Unify
                GHC.TypeLits.Extra.Solver.Operations
import-dirs: /usr/lib/ghc-8.6.1/site-local/ghc-typelits-extra-0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/ghc-typelits-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/ghc-typelits-extra-0.3
hs-libraries: HSghc-typelits-extra-0.3-3auTPQpl7g3D09kZafSvUS
depends:
    base-4.12.0.0 ghc-8.6.1 ghc-prim-0.5.3
    ghc-tcplugins-extra-0.3-D6OYfEB86xkALNc0XsqE2P
    ghc-typelits-knownnat-0.6-EKboioZbN6n8O9S8oOsEVU
    ghc-typelits-natnormalise-0.6.2-CVUPRGg5qk617hvbsPki0x
    integer-gmp-1.0.2.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
